.. Copyright 2023 Ross J. Duff MSc 
   The copyright holder licenses this file
   to you under the Apache License, Version 2.0 (the
   "License"); you may not use this file except in compliance
   with the License.  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing,
   software distributed under the License is distributed on an
   "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
   KIND, either express or implied.  See the License for the
   specific language governing permissions and limitations
   under the License.

========
OZI docs
========

Documentation and publishing.

Default Toolchain
^^^^^^^^^^^^^^^^^

* doc8_:
  An opinionated style checker for reST.
* pydocstyle_:
  A static analysis tool for checking compliance with Python docstring conventions.
* Pygments_:
  Code block syntax highlighting.
* pyparsing_:
  Support for arbitrary PEG parsing.
* Sphinx_:
  A documentation generator for Python.
* sphinx-design_:
  Responsive documentation design elements.
* sphinxawesome-codelinter_:
  Run an external tool, such as a linter, over all code blocks in your Sphinx documentation.
* sphinxawesome-theme_:
  Version 5(beta), which is easier to set up, offers your readers dark mode and is designed better. 

.. _doc8: https://pypi.org/project/doc8/
.. _pydocstyle: https://pypi.org/project/pydocstyle/
.. _Pygments: https://pypi.org/project/pygments/
.. _pyparsing: https://pypi.org/project/pyparsing/
.. _Sphinx: https://pypi.org/project/Sphinx/
.. _sphinx-design: https://pypi.org/project/sphinx-design/
.. _sphinxawesome-codelinter: https://pypi.org/project/sphinxawesome-codelinter/
.. _sphinxawesome-theme: https://pypi.org/project/sphinxawesome-theme/